.. module:: wwdtm.show

****
show
****

This module provides objects used to retrieve shows, show information,
and show details from a copy of the Wait Wait Don't Tell Me! Stats
database.

Show
====

.. autoclass:: wwdtm.show.Show
    :members:
    :inherited-members:

ShowInfo
========

.. autoclass:: wwdtm.show.ShowInfo
    :members:
    :inherited-members:

ShowInfoMultiple
================

.. autoclass:: wwdtm.show.ShowInfoMultiple
    :members:
    :inherited-members:

ShowUtility
===========

.. autoclass:: wwdtm.show.ShowUtility
    :members:
    :inherited-members:
